export declare class EntropyMaster {
    /**
     * Calculates the Shannon entropy of a given string.
     * @param input - The string to analyze.
     * @returns The entropy value, a measure of the randomness of the string.
     * @example
     * const entropy = EntropyMaster.calculateEntropy('password123');
     * console.log(entropy); // Output: a value representing entropy (e.g., 3.18)
     */
    static calculateEntropy(input: string): number;
    /**
     * Suggests if a string is strong, moderate, or weak based on its entropy.
     * @param input - The string to analyze.
     * @returns A string describing the strength: 'Strong', 'Moderate', 'Weak'.
     * @example
     * const strength = EntropyMaster.getStrength('password123');
     * console.log(strength); // Output: 'Moderate'
     */
    static getStrength(input: string): 'Strong' | 'Moderate' | 'Weak';
}
