export declare class SlugMaster {
    private static customRules;
    /**
     * Converts a string to a URL-friendly slug.
     * @example SlugMaster.slugify('Hello World!'); // 'hello-world'
     * @example SlugMaster.slugify('JavaScript Mastery'); // 'javascript-mastery'
     */
    static slugify(input: string): string;
    /**
     * Converts a string to a slug with additional options.
     * @param options An object with customizable options for the slugification process.
     * @example SlugMaster.slugifyWithOptions('Hello World!', { separator: '_', lowercase: false });
     * // 'Hello_World'
     */
    static slugifyWithOptions(input: string, options?: {
        separator?: string;
        lowercase?: boolean;
    }): string;
    /**
     * Sets custom rules for the slugification process.
     * @param rules Array of objects containing a RegExp rule and its replacement string.
     * @example SlugMaster.setCustomRules([{ rule: /and/g, replacement: 'n' }]);
     * SlugMaster.slugify('Rock and Roll'); // 'rock-n-roll'
     */
    static setCustomRules(rules: Array<{
        rule: RegExp;
        replacement: string;
    }>): void;
}
