"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.TrimmingMaster = void 0;
class TrimmingMaster {
    /**
     * Removes specified characters from the start of the string, or whitespace if none is specified.
     *
     * @example
     * TrimmingMaster.trimStart('   Hello', ' '); // 'Hello'
     *
     * @param input The input string.
     * @param chars Optional characters to trim. Defaults to whitespace.
     * @returns The modified string.
     */
    static trimStart(input, chars) {
        const pattern = chars ? new RegExp('^[' + chars.replace(/[.*+?^${}()|[\]\\]/g, '\\$&') + ']+', 'g') : /^\s+/g;
        return input.replace(pattern, '');
    }
    /**
     * Removes specified characters from the end of the string, or whitespace if none is specified.
     *
     * @example
     * TrimmingMaster.trimEnd('Hello   ', ' '); // 'Hello'
     *
     * @param input The input string.
     * @param chars Optional characters to trim. Defaults to whitespace.
     * @returns The modified string.
     */
    static trimEnd(input, chars) {
        const pattern = chars ? new RegExp('[' + chars.replace(/[.*+?^${}()|[\]\\]/g, '\\$&') + ']+$', 'g') : /\s+$/g;
        return input.replace(pattern, '');
    }
    /**
     * Collapses multiple spaces into a single space.
     *
     * @example
     * TrimmingMaster.collapseWhitespace('Hello   World! '); // 'Hello World!'
     *
     * @param input The input string.
     * @returns The string with collapsed whitespace.
     */
    static collapseWhitespace(input) {
        return input.replace(/\s+/g, ' ').trim();
    }
}
exports.TrimmingMaster = TrimmingMaster;
