export declare class ValidationMaster {
    /**
     * Checks if the string contains only alphabetic characters.
     * @example ValidationMaster.isAlpha('abc'); // true
     * @example ValidationMaster.isAlpha('abc123'); // false
     */
    static isAlpha(input: string): boolean;
    /**
     * Checks if the string contains only alphanumeric characters.
     * @example ValidationMaster.isAlphaNumeric('abc123'); // true
     * @example ValidationMaster.isAlphaNumeric('abc!123'); // false
     */
    static isAlphaNumeric(input: string): boolean;
    /**
     * Checks if the string is empty or contains only whitespace.
     * @example ValidationMaster.isEmpty(''); // true
     * @example ValidationMaster.isEmpty('   '); // true
     * @example ValidationMaster.isEmpty('abc'); // false
     */
    static isEmpty(input: string): boolean;
    /**
     * Checks if the string is in lowercase.
     * @example ValidationMaster.isLower('abc'); // true
     * @example ValidationMaster.isLower('Abc'); // false
     */
    static isLower(input: string): boolean;
    /**
     * Checks if the string contains only numeric characters.
     * @example ValidationMaster.isNumeric('123'); // true
     * @example ValidationMaster.isNumeric('123a'); // false
     */
    static isNumeric(input: string): boolean;
    /**
     * Checks if the string is in uppercase.
     * @example ValidationMaster.isUpper('ABC'); // true
     * @example ValidationMaster.isUpper('Abc'); // false
     */
    static isUpper(input: string): boolean;
    /**
     * Checks if a string starts with a given substring.
     *
     * @param input - The string to check.
     * @param substring - The substring to look for at the start.
     * @returns `true` if the input starts with the substring; otherwise, `false`.
     * @example
     * const starts = ValidationMaster.startsWith('Hello, world!', 'Hello');
     * console.log(starts); // Output: true
     */
    static startsWith(input: string, substring: string): boolean;
    /**
     * Checks if the string ends with any of the specified suffixes.
     * @example ValidationMaster.endsWith('hello', 'lo', 'world'); // true
     * @example ValidationMaster.endsWith('hello', 'hi'); // false
     */
    static endsWith(input: string, ...suffixes: string[]): boolean;
    /**
     * Compares two strings, ignoring case.
     * @example ValidationMaster.equalsIgnoreCase('Hello', 'hello'); // true
     */
    static equalsIgnoreCase(input: string, compareTo: string): boolean;
    /**
     * Checks if the string contains the specified substring.
     * @example ValidationMaster.contains('hello world', 'world'); // true
     */
    static contains(input: string, substring: string): boolean;
    /**
     * Checks if two strings are anagrams of each other.
     * @param str1 - The first string.
     * @param str2 - The second string.
     * @returns `true` if the strings are anagrams, otherwise `false`.
     * @example
     * const result = CheckMaster.isAnagram('listen', 'silent');
     * console.log(result); // Output: true
     */
    static isAnagram(str1: string, str2: string): boolean;
    /**
     * Checks if a string is a palindrome.
     * @param str - The string to check.
     * @returns `true` if the string is a palindrome, otherwise `false`.
     * @example
     * const result = CheckMaster.isPalindrome('A man, a plan, a canal, Panama');
     * console.log(result); // Output: true
     */
    static isPalindrome(str: string): boolean;
}
